import request from '@/utils/request'

// 查询外部质量反馈列表
export function listFeedback(data) {
  return request.get({
    url: '/crm/app/eqf/qualityFeedback/list',
  }, {
    isTransformResponse: false
  });
}

// 查询电阻器类型
export function listgetResistorTypeList(data) {
  return request.get({
    url: '/crm/app/eqf/qualityFeedback/listgetResistorTypeList',
  }, {
    isTransformResponse: false
  });
}

// 查询产品大类
export function listgetProductCategoriesList(data) {
  return request.get({
    url: '/crm/app/eqf/qualityFeedback/listgetProductCategoriesList',
  }, {
    isTransformResponse: false
  });
}

// 查询产品分类
export function listgetClassificationList(data) {
  return request.get({
    url: '/crm/app/eqf/qualityFeedback/listgetClassificationList',
  }, {
    isTransformResponse: false
  });
}

// 查询问题现象
export function listgetProblemPhenomenonList(data) {
  return request.get({
    url: '/crm/app/eqf/qualityFeedback/listgetProblemPhenomenonList',
  }, {
    isTransformResponse: false
  });
}

// 查询问题发生阶段
export function listgetProblemStageList(data) {
  return request.get({
    url: '/crm/app/eqf/qualityFeedback/listgetProblemStageList',
  }, {
    isTransformResponse: false
  });
}

// 查询用户诉求标签
export function listgetCustomerAppealLabelList(data) {
  return request.get({
    url: '/crm/app/eqf/qualityFeedback/listgetCustomerAppealLabelList',
  }, {
    isTransformResponse: false
  });
}

// 新增外部质量反馈
export function qualityFeedbackAdd(data) {
  return request.post({
    url: '/crm/app/eqf/qualityFeedback/qualityFeedbackAdd',
    data
  }, {
    isTransformResponse: false
  });
}



// 查询电阻器的批号
export function getMockBatchData(data) {
  return request.get({
    url: '/crm/app/eqf/qualityFeedback/getMockBatchData',
    data
  }, {
    isTransformResponse: false
  });
}



// 新增外部质量反馈明细
export function qualityFeedbackDetailAdd(data) {
  return request.post({
    url: '/crm/app/eqf/qualityFeedback/qualityFeedbackDetailAdd',
    data
  }, {
    isTransformResponse: false
  });
}

//根据合同号查询
export function getCustomerOrderList(data) {
  return request.post({
    url: '/crm/app/eqf/qualityFeedback/getCustomerOrderList',
    data
  }, {
    isTransformResponse: false
  });
}



//根据管壳合同号查询
export function getGkCustomerOrderList(data) {
  return request.post({
    url: '/crm/app/eqf/qualityFeedback/getGkCustomerOrderList',
    data
  }, {
    isTransformResponse: false
  });
}


// 新增外部质量反馈管壳明细
export function qualityFeedbackGkDetailAdd(data) {
  return request.post({
    url: '/crm/app/eqf/qualityFeedback/qualityFeedbackGkDetailAdd',
    data
  }, {
    isTransformResponse: false
  });
}

// 删除外部质量反馈
export function removeQualityFeedback(data) {
  return request.post({
    url: '/crm/app/eqf/qualityFeedback/removeQualityFeedback',
    data
  }, {
    isTransformResponse: false
  });
}

// 更新外部质量反馈状态
export function updateStatus(data) {
  return request.post({
    url: '/crm/app/eqf/qualityFeedback/updateStatus',
    data
  }, {
    isTransformResponse: false
  });
}
